class Namohelp:

    def __init__(self):
        self.welcome = 'สวัสดีฉันคือlibraryของnamo5252มีอะไรให้ช่วย'
        self.help = 'ตอนนี้namohelpยังเป็นตัวbetaอยู่ยังไม่มีระบบอะไรครับ'
        self.prison = 'คุณโครตเสี่ยงคุกเลยว่ะ'

 if __name__ == '__main__':


